@@ -6,8 +6,8 @@
 # scripts.
 #
 
-libtoolize -f
-aclocal $*
+libtoolize -f -c
+aclocal -I m4 $*
 autoheader
 autoconf
-automake --add-missing --foreign
+automake --add-missing --foreign --copy --force-missing
